.. _source:


.. raw:: html

    </center>
    <br>

.. title:: Source


**Skull, Bones and Number (OTP-CR-117/19)**


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.brokers		list of bots
    sbn.clients         clients
    sbn.command		commands
    sbn.excepts		exceptions
    sbn.handler         handler
    sbn.objects         clean namespace
    sbn.parsers         parse cli
    sbn.storage         directory
    sbn.threads         threads


**Modules**


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.cmd 	list of commands
    sbn.modules.err     show errors
    sbn.modules.flt     list of bots
    sbn.modules.fnd     locate objects
    sbn.modules.irc     internet realy chat
    sbn.modules.log     log text
    sbn.modules.mbx     mailbox
    sbn.modules.mdl     model
    sbn.modules.mod     list of modules
    sbn.modules.mre     more
    sbn.modules.pwd     sasl password
    sbn.modules.req	request
    sbn.modules.rme     readme
    sbn.modules.rss     rich site syndicate
    sbn.modules.rst     rest server
    sbn.modules.slg     slogan
    sbn.modules.tdo     todo items
    sbn.modules.thr     list of threads
    sbn.modules.tmr     timers
    sbn.modules.udp     udp to irc relay
    sbn.modules.wsd     long bad trip
